<?php
/**
 * The current version of the theme.
 */
define( 'INSPIRY_THEME_VERSION', '1.5.0' );

if ( ! function_exists( 'inspiry_theme_setup' ) ) :
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     *
     * @since 1.0.0
     */
    function inspiry_theme_setup() {

	    /**
	     * Make theme available for translation.
	     * Translations can be filed in the /languages/ directory.
	     *
	     * Note: This function supposed to be in inspiry_theme_setup,
	     * But I called it before including redux framework to support theme options translations
	     */
	    load_theme_textdomain( 'inspiry-recipe-press', get_template_directory() . '/languages' );

        // Add default posts and comments RSS feed links to head.
        add_theme_support( 'automatic-feed-links' );

        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support( 'title-tag' );

	    /*
	     * Adding Custom logo support to use it form the Appearance > Customize
	     */
	    add_theme_support( 'custom-logo', array(
		    'height'     => 200,
		    'width'      => 154,
		    'flex-width' => true,
		    'flex-height' => true
	    ) );

        /*
         * Let WordPress manage the site background.
         */
        add_theme_support( 'custom-background' );

	    /*
         * Let WordPress manage embeds in responsive views
         */
        add_theme_support( 'responsive-embeds' );

        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * See: https://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
         */
		add_theme_support( 'post-thumbnails' );

		add_theme_support( 'wp-block-styles' );

		add_theme_support( 'align-wide' );

		add_theme_support( 'editor-styles' );

	    add_editor_style( '/css/inspiry-editor-styles.css' );

	    /*
         * Enable support for custom header for the whole site.
         *
         * See: https://codex.wordpress.org/Custom_Headers
         */
	    add_theme_support( "custom-header", array( 'default-image'          => '',
	                                               'width'                  => 1200,
	                                               'height'                 => 162,
	                                               'flex-height'            => true,
	                                               'flex-width'             => true,
	                                               'uploads'                => true,
	                                               'random-default'         => false,
	                                               'header-text'            => true,
	                                               'default-text-color'     => '',
	                                               'wp-head-callback'       => '',
	                                               'admin-head-callback'    => '',
	                                               'admin-preview-callback' => '', ) );

	    // Set the default content width.
	    $GLOBALS['content_width'] = 820;

        /*
         * Used on:
         * Single post page and Post archive pages
         */
        set_post_thumbnail_size( 848, 342, true );

        /*
         * Used on:
         * Home page ( Similar recipes thumbnail for second slider variation )
         */
        add_image_size( 'inspiry-recipe-small-thumbs', 160, 160, true);

        /*
         * Used on:
         * Home What's Hot Recipe thumbnails
         * Home Latest News thumbnail
         */
        add_image_size( 'inspiry-whats-hot-recipe-thumbs', 570, 368, true );
        add_image_size( 'inspiry-whats-hot-recipe-thumbs-small', 286, 184, true );
        add_image_size( 'inspiry-whats-hot-vertical-recipe-thumbs', 286, 368, true );

        /*
         * Used on:
         * Single Recipe Slider Images
         */
        add_image_size( 'inspiry-recipe-single-slider-thumbnail', 100, 59, true );
        add_image_size( 'inspiry-recipe-single-slider-image-v1', 678, 470, true );
        add_image_size( 'inspiry-recipe-single-slider-image-v2', 845, 435, true );

        /*
         * Used on:
         * Recent Recipes and Recent Posts Widget
         */
        add_image_size( 'recent-posts-widget-thumbnail', 66, 59, true );

        /*
         * Used on:
         * Home Chefs thumbnails
         */
        add_image_size( 'inspiry-chef-listing-thumbnail', 479, 492, true );

        /*
         * Used on:
         * Recipe Listing thumbnails
         */
        add_image_size( 'inspiry-recipe-listing-thumbs', 514, 438, true );

        /*
         * Used on:
         * Recipe Listing thumbnails
         */
        add_image_size( 'inspiry-recipe-single-chef-thumbnail', 260, 233, true );

        /*
         * Theme theme uses wp_nav_menu in one location.
         */
        register_nav_menus( array(
            'main-menu' => esc_html__( 'Main Menu', 'inspiry-recipe-press' ),
            'left-menu' => esc_html__( 'Left Menu', 'inspiry-recipe-press' ),
            'right-menu' => esc_html__( 'Right Menu', 'inspiry-recipe-press' )
        ) );

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support(
            'html5',
            array(
                'search-form',
                'comment-form',
                'comment-list',
                'gallery',
                'caption'
            )
        );

        /*
         * Enable support for Post Formats.
         *
         * See: https://codex.wordpress.org/Post_Formats
         */
        add_theme_support(
            'post-formats',
            array(
                'image',
                'video',
                'gallery',
                'audio',
                'quote'
            )
        );
    }

    add_action( 'after_setup_theme', 'inspiry_theme_setup' );

endif; // inspiry_theme_setup


/**
 * Allowed HTML Tags for wp_kses() sanitization function
 *
 * @since 1.0
 */
global $inspiry_allowed_html_tags;

$inspiry_allowed_html_tags = array(
    'img' => array(
        'src' => array(),
        'class' => array(),
        'alt'   => array(),
        'style' => true
    ),'a' => array(
		'class' => array(),
        'href' => array(),
        'title' => array(),
        'rel' => array()
    ),
    'p' => array(
	    'style' => array(),
	    'class' => array()
    ),
    'br' => array(),
    'em' => array(),
    'strong' => array(
	    'class' => array(),
	    'style' => array()
    ),
    'span' => array(
	    'class' => array(),
	    'style' => array()
    ),
    'svg' => array(
	    'viewbox' => array(),
	    'width' => array(),
	    'height' => array(),
	    'class'   => array(),
	    'enable-background' => array(),
	    'xmlns' => array(),
	    'xmlns:xlink' => array(),
	    'x' => array(),
	    'y' => array(),
	    'xml:space' => array(),
	    'version' => array(),
    ),
	'path' => array(
		'class' => array(),
		'd' => array()
	),
    'circle' => array(
		'class' => array(),
		'cx' => array(),
		'cy' => array(),
		'r' => array(),
	),
    'g' => array(
	    'class' => array()
    ),
    'i' => array(
	    'class' => array()
    )
);


if( ! function_exists( 'inspiry_content_width' ) ) {
	/**
	 * Set the content width in pixels, based on the theme's design and stylesheet.
	 *
	 * Priority 0 to make it available to lower priority callbacks.
	 *
	 * @global int $content_width
	 */
	function inspiry_content_width() {

		$content_width = $GLOBALS[ 'content_width' ];

		// Get layout.
		if ( is_page_template( 'home.php' ) ) {
			$content_width = 1170;
		}

		$GLOBALS[ 'content_width' ] = apply_filters( 'inspiry_content_width', $content_width );
	}

	add_action( 'template_redirect', 'inspiry_content_width', 0 );
}


/**
 * Set the content width based on the theme's design and stylesheet.
 *
 * @since 1.0
 */
if ( ! isset( $content_width ) ) {
    $content_width = 877;
}


if( ! function_exists( 'inspiry_post_classes' ) ) {
	/**
	 * @param $classes
	 *
	 * @return array
	 */
	function inspiry_post_classes( $classes ) {

		global $post;
		$post_id = $post->ID;
		$post_type = get_post_type( $post_id );
		$format = get_post_format( $post_id );
		$classes[] = 'clearfix';

		if( 'post' == $post_type ){
			$classes[] = 'post-single';

			if ( $format == 'quote' ) {
				$quote_text = get_post_meta( $post->ID, 'inspiry_meta_quote_text', true );
				if( ! empty( $quote_text ) ){
					$classes[] = 'post-quotes';
				}
			}

			if ( ! has_post_thumbnail( $post_id ) ) {
				$classes[] = 'no-post-thumbnail';
			}
		}

		return $classes;
	}

	add_filter( 'post_class', 'inspiry_post_classes', 10, 3 );
}

/*
 * Redux Framework and Theme Options
 */
require_once( get_template_directory() . '/inc/theme-options/options-config.php' );

/*
 * Meta boxes configuration
 */
require_once( get_template_directory() . '/inc/meta-boxes/config.php' );


/*
 * TGM plugin activation
 */
require_once( get_template_directory() . '/inc/tgm/inspiry-required-plugins.php' );


/*
 * Utility functions
 */
require_once( get_template_directory() . '/inc/util/basic-functions.php' );
require_once( get_template_directory() . '/inc/util/header-functions.php' );
require_once( get_template_directory() . '/inc/util/inspiry-recipe-functions.php' );


// including theme styles
require_once( get_template_directory() . '/inc/util/theme-styles.php' );


// including theme scripts
require_once( get_template_directory() . '/inc/util/theme-scripts.php' );


// including widgetized areas
require_once( get_template_directory() . '/inc/util/widgetized-areas.php' );

// One Click Demo Import
require_once( get_template_directory() . '/inc/demo-import/demo-import.php' );