<?php
if ( ! function_exists( 'inspiry_demo_import_files' ) ) {

	/**
	 * Files for importing demo.
	 *
	 * @return array
	 * @since  1.5.0
	 */
	function inspiry_demo_import_files() {
		return array(
			array(
				'import_file_name'             => 'Default',
				'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/demo-import/default/content.xml',
				'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/demo-import/default/widgets.wie',
				'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/demo-import/default/customizer.dat',
				'local_import_redux'           => array(
					array(
						'file_path'   => trailingslashit( get_template_directory() ) . 'inc/demo-import/default/theme-options.json',
						'option_name' => 'inspiry_options',
					)
				),
				'import_preview_image_url'     => get_template_directory_uri() . '/inc/demo-import/default/screen-image.jpg',
				'preview_url'                  => 'http://recipepress-min.inspirydemos.com/',
			)
		);
	}

	add_filter( 'pt-ocdi/import_files', 'inspiry_demo_import_files' );
}


if ( ! function_exists( 'inspiry_settings_after_content_import' ) ) {
	/**
	 * Required settings after demo import.
	 */
	function inspiry_settings_after_content_import( $selected_import ) {

		$top_menu = get_term_by( 'name', 'Main Menu', 'nav_menu' );
		$footer_menu = get_term_by( 'name', 'Footer Menu', 'nav_menu' );

		set_theme_mod( 'nav_menu_locations', array(
				'main-menu' => $top_menu->term_id,
				'footer-menu' => $footer_menu->term_id,
			)
		);

		// Set homepage as front page and blog page as posts page
		$home_page = get_page_by_title( 'Home' );
		$blog_page = get_page_by_title( 'Blog' );
		if ( $home_page || $blog_page ) {
			update_option( 'show_on_front', 'page' );
		}
		if ( $home_page ) {
			update_option( 'page_on_front', $home_page->ID );
		}
		if ( $blog_page ) {
			update_option( 'page_for_posts', $blog_page->ID );
			update_option( 'posts_per_page', 5 );
		}

		$all_recipe_types = get_terms( 'recipe-type' );

		if( ! is_wp_error( $all_recipe_types ) ) {
			foreach ( $all_recipe_types as $recipe_type ) {
				$term_slug = $recipe_type->slug;
				$file_path = get_template_directory() . '/images/svg/' . $term_slug . '.php';
				if ( file_exists( $file_path ) ) {
					$meta_value = wp_remote_get( $file_path );
					if( is_array( $meta_value ) ){
						$meta_body = $meta_value['body'];
						update_term_meta( $recipe_type->term_id, 'inspiry_type_image_svg_code', $meta_body );
					}
				}
			}
		}

		global $wp_rewrite;
		$wp_rewrite->set_permalink_structure('/%postname%/');
		$wp_rewrite->flush_rules();

	}

	add_action( 'pt-ocdi/after_import', 'inspiry_settings_after_content_import' );

}

// Disable branding notice at the end of import.
add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );