<?php
/**
 * Meta box configuration file.
 */

if( !function_exists( 'inspiry_register_meta_boxes' ) ) {
    /**
     * Register meta boxes for this theme
     *
     * @param $meta_boxes
     * @return array
     * @since 1.0.0
     */
    function inspiry_register_meta_boxes ( $meta_boxes ) {

        $prefix = 'inspiry_meta_';
        $admin_email = get_option('admin_email');

        /*
         * INDEX
         * 1. Video Gallery
         * 2. Post Gallery
         * 3. Contact Page
         * 4. Pages Banner
         * 5. Homepage Banner
         * 6. Recipes Filter
         */

        /*
         * Video embed code meta box for video post format
         */
        $meta_boxes[] = array(
            'id'        => 'video-meta-box',
            'title'     => esc_html__( 'Video Embed Code', 'inspiry-recipe-press' ),
            'pages'     => array( 'post' ),
            'context'   => 'normal',
            'priority'  => 'high',
            'show'   => array(
                'post_format' => array( 'video' ), // List of post formats. Array. Case insensitive. Optional.
            ),
            'fields'    => array(
                array(
                    'name'  => esc_html__( 'Video Embed Code', 'inspiry-recipe-press' ),
                    'desc'  => esc_html__( 'If you are not using self hosted videos then please provide the video embed code and remove the width and height attributes.', 'inspiry-recipe-press' ),
                    'id'    => "{$prefix}embed_code",
                    'type'  => 'textarea',
                    'cols'  => '20',
                    'rows'  => '3'
                )
            )
        );

        /*
         * Audio upload meta box for audio post format
         */
        $meta_boxes[] = array(
            'id'        => 'audio-meta-box',
            'title'     => esc_html__( 'Audio Upload', 'inspiry-recipe-press' ),
            'pages'     => array( 'post' ),
            'context'   => 'normal',
            'priority'  => 'high',
            'show'   => array(
                'post_format' => array( 'audio' ), // List of post formats. Array. Case insensitive. Optional.
            ),
            'fields'    => array(
                array(
                    'name'  => esc_html__( 'Audio Upload', 'inspiry-recipe-press' ),
                    'desc'  => esc_html__( 'Upload audio file for audio format post. You can upload mp3, ogg and wav file formats same as html5 &lt;audio&gt; tag supports.', 'inspiry-recipe-press' ),
                    'id'    => "{$prefix}audio_url",
                    'type'  => 'file_advanced',
                    'max_file_uploads' => 4,
                    'mime_type'        => 'audio' // Leave blank for all file types
                )
            )
        );

        /*
         * Quote meta box for quote post format
         */
        $meta_boxes[] = array(
            'id'        => 'quote-meta-box',
            'title'     => esc_html__( 'Quote Upload', 'inspiry-recipe-press' ),
            'pages'     => array( 'post' ),
            'context'   => 'normal',
            'priority'  => 'high',
            'show'   => array(
                'post_format' => array( 'quote' ), // List of post formats. Array. Case insensitive. Optional.
            ),
            'fields'    => array(
                array(
                    'name'  => esc_html__( 'Quote Text', 'inspiry-recipe-press' ),
                    'desc'  => esc_html__( 'Provide quote text in this field.', 'inspiry-recipe-press' ),
                    'id'    => "{$prefix}quote_text",
                    'type'  => 'textarea',
                    'cols'  => '20',
                    'rows'  => '3'
                ),
                array(
                    'name'  => esc_html__( 'Quote Author', 'inspiry-recipe-press' ),
                    'desc'  => esc_html__( 'Provide author name for this quote.', 'inspiry-recipe-press' ),
                    'id'    => "{$prefix}quote_author",
                    'type'  => 'text'
                )
            )
        );

        /*
         * Gallery Meta Box
         */
        $meta_boxes[] = array(
            'id'        => 'gallery-meta-box',
            'title'     => esc_html__( 'Gallery Images', 'inspiry-recipe-press'),
            'pages'     => array( 'post' ),
            'context'   => 'normal',
            'priority'  => 'high',
            'show'   => array(
                'post_format' => array( 'gallery' ), // List of post formats. Array. Case insensitive. Optional.
            ),
            'fields'    => array(
                array(
                    'name'  => esc_html__( 'Upload Gallery Images', 'inspiry-recipe-press' ),
                    'id'    => "{$prefix}gallery",
                    'desc'  => esc_html__( 'Images should have minimum width of 850px and minimum height of 567px, Bigger size images will be cropped automatically.', 'inspiry-recipe-press' ),
                    'type'  => 'image_advanced',
                    'max_file_uploads' => 48
                )
            )
        );

        /*
         * Contact Meta Box
         */
        $meta_boxes[] = array(
            'id'        => 'contact-meta-box',
            'title'     => esc_html__( 'Contact Page Information', 'inspiry-recipe-press'),
            'pages'     => array( 'page' ),
            'context'   => 'normal',
            'priority'  => 'high',
            'tabs'      => array(
                'widgets-section' => array(
                    'label' => esc_html__( 'Widgets Area', 'inspiry-recipe-press' ),
                    'icon'  => 'dashicons-admin-settings',
                ),
                'contact-form' => array(
	                'label' => esc_html__( 'Contact Form', 'inspiry-recipe-press' ),
	                'icon'  => 'dashicons-email',
                ),
                'google-map'  => array(
	                'label' => esc_html__( 'Google Map', 'inspiry-recipe-press' ),
	                'icon'  => 'dashicons-location'
                )
            ),
            // Tab style: 'default', 'box' or 'left'. Optional
            'tab_style' => 'left',
            'show'   => array(
                // List of page templates (used for page only). Array. Optional.
                'template'    => array( 'page-templates/contact.php' ),
            ),
            'fields'    => array(
	            array(
		            'id'    => "inspiry_widget_section_heading",
		            'name'  => esc_html__( 'Widget Section Heading', 'inspiry-recipe-press' ),
		            'type'  => 'text',
		            'std'   => esc_html__( 'Our Locations', 'inspiry-recipe-press' ),
		            'tab'   => 'widgets-section'
	            ),
	            array(
		            'id'    => "inspiry_contact_form_heading",
		            'name'  => esc_html__( 'Contact Form Heading', 'inspiry-recipe-press' ),
		            'type'  => 'text',
		            'std'   => esc_html__( 'Send Us a Message', 'inspiry-recipe-press' ),
		            'tab'   => 'contact-form',
	            ),
	            array(
		            'id'    => "inspiry_contact_form_7",
		            'name'  => esc_html__( 'Contact Form 7 Shortcode', 'inspiry-recipe-press' ),
		            'desc'  => esc_html__( 'Add form shortcode you have created using Contact Form 7 Plugin.', 'inspiry-recipe-press' ),
		            'type'  => 'text',
		            'tab'   => 'contact-form',
	            ),
                array(
                    'id'    => "inspiry_map_address",
                    'name'  => esc_html__( 'Office Address', 'inspiry-recipe-press' ),
                    'desc'  => esc_html__( 'Leaving it empty will hide the google map.', 'inspiry-recipe-press'),
                    'type'  => 'text',
                    'std'   => '121 King St, Melbourne VIC 3000, Australia',
                    'size'  => 50,
                    'tab'   => 'google-map',
                ),
                array(
                    'id'    => "inspiry_map_location",
                    'name'  => esc_html__( 'Office Location', 'inspiry-recipe-press' ),
                    'desc'  => esc_html__( 'Drag the marker to point your office location. You can also use the address field above to search for your address.', 'inspiry-recipe-press' ),
                    'type'  => 'map',
                    'std'   => '-37.817314,144.955431',         // 'latitude,longitude[,zoom]' (zoom is optional)
                    'style' => 'width: 95%; height: 400px',
                    'address_field' => "inspiry_map_address",
                    'tab'   => 'google-map',
                ),
                array(
                    'id'   => 'inspiry_map_zoom',
                    'type' => 'slider',
                    'name' => esc_html__( 'Map Zoom Level', 'inspiry-recipe-press' ),
                    'desc' => esc_html__( 'Zoom level for resulted map on contact page.', 'inspiry-recipe-press'),
                    // jQuery UI slider options. See here http://api.jqueryui.com/slider/
                    'js_options' => array(
                        'min'   => 6,
                        'max'   => 18,
                        'step'  => 1,
                    ),
                    'std'   => 14,
                    'tab'   => 'google-map',
                )
            )
        );

	    /*
         * Submit Meta Box
         */
	    $meta_boxes[] = array(
		    'id'        => 'submit-recipe-meta-box',
		    'title'     => esc_html__( 'Submit Page Information', 'inspiry-recipe-press'),
		    'pages'     => array( 'page' ),
		    'context'   => 'normal',
		    'priority'  => 'high',
		    'show'   => array(
			    // List of page templates (used for page only). Array. Optional.
			    'template'    => array( 'page-templates/submit-recipe.php' ),
		    ),
		    'fields'    => array(
			    array(
				    'id'   => 'inspiry_submit_recipe_edit_title',
				    'type' => 'text',
				    'name' => esc_html__( 'Edit Recipe Page Title', 'inspiry-recipe-press' ),
				    'desc' => esc_html__( 'This title will appear when an existing recipe is being edited instead new submission.', 'inspiry-recipe-press'),
				    'std'   => esc_html__('Edit Recipe', 'inspiry-recipe-press' ),
			    )
		    )
	    );

        /*
         * Chef Meta Boxes
         */

        $inspiry_chefs_array = array( 0 => esc_html__( 'None', 'inspiry-recipe-press' ) );
        if ( class_exists( 'Inspiry_Recipes' ) ) {
            $inspiry_chefs_array = array( 0 => esc_html__( 'None', 'inspiry-recipe-press' ) );
            $chefs_posts = get_posts( array (
                'post_type' => 'inspiry_chef',
                'posts_per_page' => 100,
                'suppress_filters' => 0,
            ) );
            if ( ! empty ( $chefs_posts ) ) {
                foreach ( $chefs_posts as $chefs_post ) {
                    $inspiry_chefs_array[ $chefs_post->ID ] = $chefs_post->post_title;
                }
            }
        }

        $meta_boxes[] = array(
            'id'        => 'chefs-page-meta-box',
            'title'     => esc_html__( 'Chefs Page Information', 'inspiry-recipe-press'),
            'pages'     => array( 'page' ),
            'context'   => 'normal',
            'priority'  => 'high',
            'show'   => array(
                'template'    => array( 'page-templates/chefs.php' ),
            ),
            'fields'    => array(
                array(
                    'id'    => 'inspiry_head_chef_id',
                    'name'  => esc_html__( 'Head Chef ID', 'inspiry-recipe-press' ),
                    'std'   => null,
                    'type' => 'select',
                    'options' => $inspiry_chefs_array,
                ),
                array(
                    'id'    => 'inspiry_head_chef_title',
                    'name'  => esc_html__( 'Head Chef Title', 'inspiry-recipe-press' ),
                    'desc'  => esc_html__( 'It will only appear if head chef is provided.', 'inspiry-recipe-press' ),
                    'type'  => 'text',
                    'std'   => esc_html__( 'Head Chef', 'inspiry-recipe-press' )
                ),
                array(
                    'id'    => 'inspiry_chef_team_title',
                    'name'  => esc_html__( 'Chefs Team Title', 'inspiry-recipe-press' ),
                    'type'  => 'text',
                    'std'   => esc_html__( 'Chef Team', 'inspiry-recipe-press' )
                ),
                array(
                    'id'    => 'inspiry_chef_count',
                    'name'  => esc_html__( 'Chefs Per Page', 'inspiry-recipe-press' ),
                    'type'  => 'text',
                    'std'   => 12
                )
            )
        );

        /*
         * Banner meta box for home page templates
         */
        $meta_boxes[] = array(
            'id'        => 'home-banner-meta-box',
            'title'     => esc_html__( 'Banner Settings', 'inspiry-recipe-press' ),
            'pages'     => array( 'page' ),
            'context'   => 'normal',
            'priority'  => 'low',
            'show'   => array(
                'template'    => array( 'page-templates/home.php' ),
            ),
            'fields' => array(
                array(
                    'name'  => esc_html__( 'Home Banner Image', 'inspiry-recipe-press' ),
                    'id'    => "{$prefix}home_banner_image",
                    'desc'  => esc_html__( 'Banner image should have minimum width of 1900px and minimum height of 258px.', 'inspiry-recipe-press' ),
                    'type'  => 'image_advanced',
                    'max_file_uploads' => 1
                ),
                array(
                    'name'  => esc_html__( 'Banner Title', 'inspiry-recipe-press' ),
                    'id'    => "inspiry_home_banner_title",
                    'desc'  => esc_html__( 'Leave empty if you want no title on banner image.', 'inspiry-recipe-press' ),
                    'type'  => 'text'
                )
            )
        );

        /*
         * Banner meta box
         */
        $meta_boxes[] = array(
            'id'        => 'banner-meta-box',
            'title'     => esc_html__( 'Banner Settings', 'inspiry-recipe-press' ),
            'pages'     => array( 'post', 'page', 'inspiry_chef' ),
            'context'   => 'normal',
            'priority'  => 'low',
            'hide'   => array(
                'template'    => array(
                    'page-templates/home.php',
                ),
            ),
            'fields' => array(
                array(
                    'name'  => esc_html__( 'Banner Image', 'inspiry-recipe-press' ),
                    'id'    => "{$prefix}page_banner_image",
                    'desc'  => esc_html__( 'Banner image should have minimum width of 2000px and minimum height of 320px.', 'inspiry-recipe-press' ),
                    'type'  => 'image_advanced',
                    'max_file_uploads' => 1
                )
            )
        );

        // apply a filter before returning meta boxes
        $meta_boxes = apply_filters( 'inspiry_theme_meta', $meta_boxes );

        return $meta_boxes;

    }

    add_filter( 'rwmb_meta_boxes', 'inspiry_register_meta_boxes' );

}