<?php
/*
 * Home Options
 */

global $opt_name;
Redux::setSection( $opt_name, array(
    'title' => esc_html__('Home', 'inspiry-recipe-press'),
    'id'    => 'home-section',
    'desc'  => esc_html__('This section contains options for homepage.', 'inspiry-recipe-press'),
    'fields'=> array(
        array(
            'id'       => 'inspiry_home_module_below_header',
            'type'     => 'button_set',
            'title'    => esc_html__( 'What to display below header', 'inspiry-recipe-press' ),
            'options'  => array(
                'slider'        => esc_html__( 'Slider', 'inspiry-recipe-press' ),
                'banner'        => esc_html__( 'Image Banner', 'inspiry-recipe-press' )
            ),
            'default'  => 'slider',
        ),
        array(
            'id'        => 'inspiry_slider_type',
            'type'      => 'image_select',
            'title'     => esc_html__( 'Select the type of slider', 'inspiry-recipe-press' ),
            'options'   => array(
                '1' => array(
                    'alt' => esc_html__('Boxed Slider Variation One', 'inspiry-recipe-press'),
                    'img' => get_template_directory_uri() . '/inc/theme-options/images/home/slider-v1.jpg',
                ),
                '2' => array(
                    'alt' => esc_html__('Boxed Slider Variation Two', 'inspiry-recipe-press'),
                    'img' => get_template_directory_uri() . '/inc/theme-options/images/home/slider-v2.jpg',
                ),
                '3' => array(
                    'alt' => esc_html__('Boxed Slider Variation Three', 'inspiry-recipe-press'),
                    'img' => get_template_directory_uri() . '/inc/theme-options/images/home/slider-v3.jpg',
                ),
                '4' => array(
                    'alt' => esc_html__('Full Width Slider Variation One', 'inspiry-recipe-press'),
                    'img' => get_template_directory_uri() . '/inc/theme-options/images/home/slider-v4.jpg',
                )
            ),
            'default'   => '1',
            'required' => array( 'inspiry_home_module_below_header', '=', 'slider' ),
        ),
        array(
            'id'       => 'inspiry_slider_v3_search_type',
            'type'     => 'button_set',
            'title'    => esc_html__( 'Select search type for slider variation three.', 'inspiry-recipe-press' ),
            'options'  => array(
                'simple-search'        => esc_html__( 'Simple Search Before Slider', 'inspiry-recipe-press' ),
                'advanced-search'        => esc_html__( 'Advance Search After Slider', 'inspiry-recipe-press' )
            ),
            'default'  => 'simple-search',
            'required'  => array( 'inspiry_slider_type', '=', '3' )
        ),
        array(
            'id'       => 'inspiry_home_slides_number',
            'type'     => 'select',
            'title'    => esc_html__( 'Number of slides to display', 'inspiry-recipe-press' ),
            'options'  => array(
                1 => '1',
                2 => '2',
                3 => '3',
                4 => '4',
                5 => '5',
                6 => '6',
                7 => '7',
            ),
            'default'  => 3,
            'select2'  => array( 'allowClear' => false ),
            'required' => array( 'inspiry_home_module_below_header', '=', 'slider' )
        ),
        array(
            'id'        => 'inspiry_home_slides_corner_image',
            'type'      => 'media',
            'title'     => esc_html__( 'Corner Image', 'inspiry-recipe-press' ),
            'subtitle'  => esc_html__( 'Upload an image for corner of slider section. Image will not appear on full width slider.', 'inspiry-recipe-press' ),
            'required' => array( 'inspiry_slider_type', '!=', '3' )
        ),
        array(
            'id'       => 'inspiry_home_slides_corner_image_side',
            'type'     => 'button_set',
            'title'    => esc_html__( 'Select a side for corner image', 'inspiry-recipe-press' ),
            'options'  => array(
                'left-bottom'        => esc_html__( 'Left Bottom', 'inspiry-recipe-press' ),
                'right-bottom'        => esc_html__( 'Right Bottom', 'inspiry-recipe-press' )
            ),
            'default'  => 'left-bottom',
            'required' => array( 'inspiry_slider_type', '!=', '3' )
        ),
        array(
            'id'            => 'inspiry_home_slides_corner_image_margin',
            'type'          => 'spacing',
            'output'        => array( '.slider-corner-image' ),
            'mode'          => 'margin',
            'title'         => esc_html__( 'Margins', 'inspiry-recipe-press' ),
            'desc'         => esc_html__( 'Give margins according to your side selections. Left margin for left bottom side and right for right bottom.', 'inspiry-recipe-press' ),
            'units'          => array( 'em', 'px' ),
            'units_extended' => 'false',
            'top'           => false,
            'default'            => array(
                'margin-right'   => '-300px',
                'margin-bottom'  => '-100px',
                'margin-left'    => '',
                'units'          => 'px'
            ),
            'required' => array( 'inspiry_slider_type', '!=', '3' )
        )
    ) )
);


/*
 * Layout Sub Section
 */
Redux::setSection( $opt_name, array(
    'title' => esc_html__( 'Layout', 'inspiry-recipe-press' ),
    'id'    => 'layout-section',
    'desc'  => esc_html__( 'This section contains homepage layout related options.', 'inspiry-recipe-press' ),
    'subsection' => true,
    'fields'=> array(
        array(
            'id'      => 'inspiry_home_sections',
            'type'    => 'sorter',
            'title'   => esc_html__( 'Homepage layout manager', 'inspiry-recipe-press' ),
            'desc'    => esc_html__( 'Organize homepage sections in the way you want them to appear.', 'inspiry-recipe-press' ),
            'options' => array(
                'enabled'  => array(
	                'whats-hot'             => esc_html__( 'What\'s Hot', 'inspiry-recipe-press' ),
	                'our-chefs'             => esc_html__( 'Our Chefs', 'inspiry-recipe-press' ),
	                'latest-news'           => esc_html__( 'Latest News', 'inspiry-recipe-press' ),
	                'special-recipe-widget'   => esc_html__( 'Special Recipe', 'inspiry-recipe-press' )
                ),
                'disabled' => array(
                    'big-banner'             => esc_html__( 'Big Banner', 'inspiry-recipe-press' ),
                    'contents'       => esc_html__( 'Page Contents', 'inspiry-recipe-press' ),
                    //'info-section'          => esc_html__( 'Info Section', 'inspiry-recipe-press' )
                )
            )
        ),
	    array(
		    'id'       => 'inspiry_home_default_section_wide',
		    'type'     => 'switch',
		    'title'    => esc_html__( 'Make Default Contents Section Full Wide?', 'inspiry-recipe-press' ),
		    'desc'    => esc_html__( 'This options can be used if you are planning to add contents using page builders like Elementor, Visual Composer, etc.', 'inspiry-recipe-press' ),
		    'default'  => 0,
		    'on'       => esc_html__( 'Yes', 'inspiry-recipe-press' ),
		    'off'      => esc_html__( 'No', 'inspiry-recipe-press' ),
	    ),
    )
) );


if ( class_exists( 'Inspiry_Recipes' ) ) {

    /* What's Hot Home Sub Section */
	require_once get_template_directory() . '/inc/theme-options/home-options/whats-hot-options.php';

    /* Chefs Home Sub Section */
	require_once get_template_directory() . '/inc/theme-options/home-options/chef-options.php';

}


/* Latest News Home Sub Section */
require_once get_template_directory() . '/inc/theme-options/home-options/news-options.php';

/* Big Banner Home Sub Section */
require_once get_template_directory() . '/inc/theme-options/home-options/banner-options.php';

/* Special Recipe Home Sub Section */
require_once get_template_directory() . '/inc/theme-options/home-options/special-recipe-options.php';