<?php
/*
 * Home News Options
 */

global $opt_name;

$news_array = array();
$news_posts = get_posts( array (
    'post_type' => 'post',
    'posts_per_page' => 50,
    'suppress_filters' => 0,
) );

Redux::setSection(
    $opt_name,
    array(
        'title' => esc_html__( 'Latest News', 'inspiry-recipe-press' ),
        'id'    => 'latest-news-home-section',
        'desc'  => esc_html__( 'This section contains home latest news related options.', 'inspiry-recipe-press' ),
        'subsection' => true,
        'fields'=> array(
            array(
                'id'        => 'inspiry_home_latest_news_variation',
                'type'      => 'image_select',
                'title'     => esc_html__( 'Latest News variations', 'inspiry-recipe-press' ),
                'subtitle'  => esc_html__( 'Select the design variation that you want to use for homepage latest news section.', 'inspiry-recipe-press' ),
                'options'   => array(
                    '1' => array(
                        'alt' => esc_html__('1st Variation', 'inspiry-recipe-press'),
                        'img' => get_template_directory_uri() . '/inc/theme-options/images/home/news-v1.jpg',
                    ),
                    '2' => array(
                        'alt' => esc_html__('2nd Variation', 'inspiry-recipe-press'),
                        'img' => get_template_directory_uri() . '/inc/theme-options/images/home/news-v2.jpg',
                    ),
                    '3' => array(
                        'alt' => esc_html__('3rd Variation', 'inspiry-recipe-press'),
                        'img' => get_template_directory_uri() . '/inc/theme-options/images/home/news-v3.jpg',
                    )
                ),
                'default'   => '1',
            ),
            array(
                'id'        => 'inspiry_home_latest_news_title',
                'type'      => 'text',
                'title'     => esc_html__( 'Latest News Title', 'inspiry-recipe-press' ),
                'default'   => esc_html__( 'Latest News', 'inspiry-recipe-press' )
            ),
            array(
                'id'   => 'inspiry_home_latest_news_count',
                'type'     => 'select',
                'title'    => esc_html__( 'Number of posts to display', 'inspiry-recipe-press' ),
                'options'  => array(
                    4  => '4',
                    8  => '8',
                    12  => '12',
                    16  => '16',
                    20  => '20'
                ),
                'default'  => 4,
                'select2'  => array( 'allowClear' => false )
            ),
            array(
                'id'       => 'inspiry_home_latest_news_type',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Type of News Posts', 'inspiry-recipe-press' ),
                'desc' => esc_html__( 'Choose the type of news posts to display on homepage.', 'inspiry-recipe-press' ),
                'options'  => array(
                    'recent' => esc_html__('Recent', 'inspiry-recipe-press'),
                    'category' => esc_html__('Based on Category', 'inspiry-recipe-press'),
                    'tag' => esc_html__('Based on Tag', 'inspiry-recipe-press'),
                ),
                'default'  => 'recent',
            ),
            array(
                'id'       => 'inspiry_home_latest_news_category',
                'type'     => 'select',
                'data'     => 'categories',
                'title'    => esc_html__( 'Select a Category', 'inspiry-recipe-press' ),
                'required' => array( 'inspiry_home_latest_news_type', '=', 'category' ),
            ),
            array(
                'id'       => 'inspiry_home_latest_news_tag',
                'type'     => 'select',
                'data'     => 'tags',
                'title'    => esc_html__( 'Select a Tag', 'inspiry-recipe-press' ),
                'required' => array( 'inspiry_home_latest_news_type', '=', 'tag' ),
            ),
            array(
                'id'        => 'inspiry_home_skip_post_ids',
                'type'      => 'textarea',
                'title'     => esc_html__( 'Post IDs skip', 'inspiry-recipe-press' ),
                'subtitle'  => esc_html__( 'Provide comma separated IDs for posts you want to skip from this listing.', 'inspiry-recipe-press' ),
                'desc'      => esc_html__( 'Example: 2,15,26,34', 'inspiry-recipe-press' ),
                'rows'      => 2
            ),
            array(
                'id'       => 'inspiry_home_latest_news_link_text',
                'type'     => 'text',
                'title'    => esc_html__( 'Read More Link Text', 'inspiry-recipe-press' ),
                'default'  => esc_html__( 'Read More', 'inspiry-recipe-press' ),
            ),
            array(
                'id'        => 'inspiry_home_news_corner_image',
                'type'      => 'media',
                'title'     => esc_html__( 'Corner Image', 'inspiry-recipe-press' ),
                'subtitle'  => esc_html__( 'Upload an image for corner of chef section. Image will not appear on full width slider.', 'inspiry-recipe-press' ),
                'required' => array( 'inspiry_home_latest_news_variation', 'equals', '1' )
            ),
            array(
                'id'       => 'inspiry_home_news_corner_image_side',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Select a side for corner image', 'inspiry-recipe-press' ),
                'options'  => array(
                    'left-bottom'        => esc_html__( 'Left Bottom', 'inspiry-recipe-press' ),
                    'right-bottom'        => esc_html__( 'Right Bottom', 'inspiry-recipe-press' )
                ),
                'default'  => 'left-bottom',
                'required' => array( 'inspiry_home_latest_news_variation', 'equals', '1' )
            ),
            array(
                'id'            => 'inspiry_home_news_corner_image_margin',
                'type'          => 'spacing',
                'output'        => array( '.news-corner-image' ),
                'mode'          => 'margin',
                'title'         => esc_html__( 'Margins', 'inspiry-recipe-press' ),
                'desc'         => esc_html__( 'Give margins according to your side selections. Left margin for left bottom side and right for right bottom.', 'inspiry-recipe-press' ),
                'units'          => array( 'em', 'px' ),
                'units_extended' => 'false',
                'top'           => false,
                'default'            => array(
                    'margin-right'   => '',
                    'margin-bottom'  => '-110px',
                    'margin-left'    => '-240px',
                    'units'          => 'px'
                ),
                'required' => array( 'inspiry_home_latest_news_variation', 'equals', '1' )
            )
        )
    )
);