<?php
/*
 * Search Options
 */
global $opt_name;

$all_pages = get_pages();
$pages_options = $default_selected_pages = array();
$default_templates = array(
	'page-templates/home.php',
	'page-templates/recipes.php'
);
if( is_array( $all_pages ) && count( $all_pages ) > 0 ) {
	foreach ( $all_pages as $single_page ) {
		//var_dump($pages);
		if ( get_page_template_slug( $single_page->ID ) != 'page-templates/recipe-search.php' ) {
			$pages_options[ $single_page->ID ] = $single_page->post_title;
		}
		if ( in_array( get_page_template_slug( $single_page->ID ), $default_templates ) ) {
			$default_selected_pages[] = $single_page->ID;
		}
	}
}

Redux::setSection( $opt_name, array(
    'title' => esc_html__( 'Search', 'inspiry-recipe-press' ),
    'id'    => 'search-section',
    'desc'  => esc_html__( 'This section contains options related to recipe search.', 'inspiry-recipe-press' ),
    'fields'=> array(

        array(
            'id'       => 'inspiry_advance_search_enable',
            'type'     => 'switch',
            'title'    => esc_html__( 'Enable Advanced Recipe Search', 'inspiry-recipe-press' ),
            'default'  => 1,
            'on'       => esc_html__( 'Enable', 'inspiry-recipe-press' ),
            'off'      => esc_html__( 'Disable', 'inspiry-recipe-press' ),
        ),
        array(
            'id'       => 'inspiry_search_form_title',
            'type'     => 'text',
            'title'    => esc_html__( 'Search Form Title', 'inspiry-recipe-press' ),
            'default'  => esc_html__( 'Find Recipes', 'inspiry-recipe-press' ),
        ),
        array(
            'id'       => 'inspiry_search_page',
            'type'     => 'select',
            'data'     => 'pages',
            'title'    => esc_html__( 'Recipe Search Page', 'inspiry-recipe-press' ),
            'subtitle' => esc_html__( 'Select a page for recipes search results.', 'inspiry-recipe-press' ),
            'desc'     => esc_html__( 'Make sure the selected page is using Recipe Search template.', 'inspiry-recipe-press' ),
        ),
        array(
            'id'       => 'inspiry_search_recipes_number',
            'type'     => 'select',
            'title'    => esc_html__( 'Number of Recipes on Search Page', 'inspiry-recipe-press' ),
            'options'  => array(
                3 => '3',
                6 => '6',
                9 => '9',
                12 => '12'
            ),
            'default'  => 6,
            'select2'  => array( 'allowClear' => false ),
        ),
	    array(
		    'id'       => 'inspiry_search_form_default_state',
		    'type'     => 'switch',
		    'title'    => esc_html__( 'Default State of Search Form', 'inspiry-recipe-press' ),
		    'default'  => 1,
		    'on'       => esc_html__( 'Opened', 'inspiry-recipe-press' ),
		    'off'      => esc_html__( 'Closed', 'inspiry-recipe-press' )
	    ),
        array(
            'id'      => 'inspiry_search_fields',
            'type'    => 'sorter',
            'title'   => esc_html__('Search Form Fields Manager', 'inspiry-recipe-press'),
            'options' => array(
                'enabled'  => array(
                    'recipe-type'       => esc_html__( 'Recipe Type', 'inspiry-recipe-press' ),
                    'course'            => esc_html__( 'Course', 'inspiry-recipe-press' ),
                    'cuisine'           => esc_html__( 'Cuisine', 'inspiry-recipe-press' ),
                    'skill-level'       => esc_html__( 'Skill Level', 'inspiry-recipe-press' )
                ),
                'disabled' => array(
                    'chef'          => esc_html__( 'Chef', 'inspiry-recipe-press' )
                ),
            )
        ),
	    array(
		    'id'       => 'inspiry_search_form_pages',
		    'type'     => 'checkbox',
		    'title'    => esc_html__( 'Pages to show advance search form on', 'inspiry-recipe-press' ),
		    'subtitle' => esc_html__( 'Select the pages you want to show form on.', 'inspiry-recipe-press' ),
		    'options'  => $pages_options,
		    'default' => $default_selected_pages
	    ),
	    array(
		    'id'       => 'inspiry_search_form_on_taxonomies',
		    'type'     => 'switch',
		    'title'    => esc_html__( 'Search Form on Taxonomy Templates', 'inspiry-recipe-press' ),
		    'subtitle' => esc_html__( 'Do you want to show search form on recipe related taxonomy templates?', 'inspiry-recipe-press' ),
		    'default'  => 1,
		    'on'       => esc_html__( 'Show', 'inspiry-recipe-press' ),
		    'off'      => esc_html__( 'Hide', 'inspiry-recipe-press' )
	    ),
	    array(
		    'id'       => 'inspiry_search_form_on_category',
		    'type'     => 'switch',
		    'title'    => esc_html__( 'Search Form on Category Templates', 'inspiry-recipe-press' ),
		    'subtitle' => esc_html__( 'Do you want to show search form on blog category templates?', 'inspiry-recipe-press' ),
		    'default'  => 1,
		    'on'       => esc_html__( 'Show', 'inspiry-recipe-press' ),
		    'off'      => esc_html__( 'Hide', 'inspiry-recipe-press' )
	    ),
	    array(
		    'id'       => 'inspiry_search_form_on_tags',
		    'type'     => 'switch',
		    'title'    => esc_html__( 'Search Form on Tag Templates', 'inspiry-recipe-press' ),
		    'subtitle' => esc_html__( 'Do you want to show search form on tag templates?', 'inspiry-recipe-press' ),
		    'default'  => 1,
		    'on'       => esc_html__( 'Show', 'inspiry-recipe-press' ),
		    'off'      => esc_html__( 'Hide', 'inspiry-recipe-press' )
	    ),
	    array(
		    'id'       => 'inspiry_search_form_on_recipe_single',
		    'type'     => 'switch',
		    'title'    => esc_html__( 'Search Form on Single Recipe Template', 'inspiry-recipe-press' ),
		    'subtitle' => esc_html__( 'Do you want to show search form on single recipe template?', 'inspiry-recipe-press' ),
		    'default'  => 1,
		    'on'       => esc_html__( 'Show', 'inspiry-recipe-press' ),
		    'off'      => esc_html__( 'Hide', 'inspiry-recipe-press' )
	    ),
	    array(
		    'id'       => 'inspiry_search_form_on_blog_single',
		    'type'     => 'switch',
		    'title'    => esc_html__( 'Search Form on Single Post Template', 'inspiry-recipe-press' ),
		    'subtitle' => esc_html__( 'Do you want to show search form on single post template?', 'inspiry-recipe-press' ),
		    'default'  => 1,
		    'on'       => esc_html__( 'Show', 'inspiry-recipe-press' ),
		    'off'      => esc_html__( 'Hide', 'inspiry-recipe-press' )
	    ),
	    array(
		    'id'       => 'inspiry_search_form_on_archives',
		    'type'     => 'switch',
		    'title'    => esc_html__( 'Search Form on Archive Templates', 'inspiry-recipe-press' ),
		    'subtitle' => esc_html__( 'Do you want to show search form on other archive template?', 'inspiry-recipe-press' ),
		    'default'  => 1,
		    'on'       => esc_html__( 'Show', 'inspiry-recipe-press' ),
		    'off'      => esc_html__( 'Hide', 'inspiry-recipe-press' )
	    ),

    ) ) );