<?php
if( !function_exists( 'inspiry_get_file_icon' ) ) :
    /**
     * Return font awesome icon based on file extnsion
     * @param string $extension file extension
     * @return string
     */
    function inspiry_get_file_icon( $extension ) {

        switch ( $extension ) {
            /* PDF */
            case 'pdf':
                return '<i class="fa fa-file-pdf-o"></i>';

            /* Images */
            case 'jpg':
            case 'png':
            case 'gif':
            case 'bmp':
            case 'jpeg':
            case 'tiff':
            case 'tif':
                return '<i class="fa fa-file-image-o"></i>';

            /* Text */
            case 'txt':
            case 'log':
            case 'tex':
                return '<i class="fa fa-file-text-o"></i>';

            /* Documents */
            case 'doc':
            case 'odt':
            case 'msg':
            case 'docx':
            case 'rtf':
            case 'wps':
            case 'wpd':
            case 'pages':
                return '<i class="fa fa-file-word-o"></i>';

            /* Spread Sheets */
            case 'csv':
            case 'xlsx':
            case 'xls':
            case 'xml':
            case 'xlr':
                return '<i class="fa fa-file-excel-o"></i>';

            /* Zip */
            case 'zip':
            case 'rar':
            case '7z':
            case 'zipx':
            case 'tar.gz':
            case 'gz':
            case 'pkg':
                return '<i class="fa fa-file-zip-o"></i>';

            /* Audio */
            case 'mp3':
            case 'wav':
            case 'm4a':
            case 'aif':
            case 'wma':
            case 'ra':
            case 'mpa':
            case 'iff':
            case 'm3u':
                return '<i class="fa fa-file-audio-o"></i>';

            /* Video */
            case 'avi':
            case 'flv':
            case 'm4v':
            case 'mov':
            case 'mp4':
            case 'mpg':
            case 'rm':
            case 'swf':
            case 'wmv':
                return '<i class="fa fa-file-video-o"></i>';

            /* Others */
            default:
                return '<i class="fa fa-file-o"></i>';
        }

    }

endif;


if( !function_exists( 'inspiry_recipe_search' ) ) {
    /**
     * Offers recipe search functionality
     *
     * @param $search_args (array) search arguments
     * @return mixed (array) modified search arguments
     */
    function inspiry_recipe_search( $search_args ) {

        /* taxonomy query and meta query arrays */
        $tax_query = array();
        $meta_query = array();

        /* Keyword Based Search */
        if( isset ( $_GET['keyword'] ) ) {
            $keyword = trim( $_GET['keyword'] );
            if ( ! empty( $keyword ) ) {
                $search_args['s'] = $keyword;
            }
        }

        /* recipe type taxonomy query */
        if( ( !empty( $_GET['type'] ) ) && ( $_GET['type'] != 'any') ){
            $tax_query[] = array(
                'taxonomy' => 'recipe-type',
                'field' => 'slug',
                'terms' => $_GET['type']
            );
        }

        /* recipe cuisine taxonomy query */
        if((!empty($_GET['cuisine'])) && ( $_GET['cuisine'] != 'any' ) ){
            $tax_query[] = array(
                'taxonomy' => 'inspiry-cuisine',
                'field' => 'slug',
                'terms' => $_GET['cuisine']
            );
        }

        /* recipe course taxonomy query */
        if((!empty($_GET['course'])) && ( $_GET['course'] != 'any' ) ){
            $tax_query[] = array(
                'taxonomy' => 'inspiry-course',
                'field' => 'slug',
                'terms' => $_GET['course']
            );
        }

        /* recipe skill level taxonomy query */
        if((!empty($_GET['level'])) && ( $_GET['level'] != 'any' ) ){
            $tax_query[] = array(
                'taxonomy' => 'skill-level',
                'field' => 'slug',
                'terms' => $_GET['level']
            );
        }

        /* recipe chef meta query */
        if( isset($_GET['chef']) && ($_GET['chef'] != 'any') ){
            $meta_query[] = array(
                'key' => 'inspiry_recipe_chefs',
                'value' => $_GET['chef'],
                'type' => 'NUMERIC',
                'compare' => '='
            );
        }


        /* if more than one taxonomies exist then specify the relation */
        $tax_count = count( $tax_query );
        if( $tax_count > 1 ){
            $tax_query['relation'] = 'AND';
        }

        /* if more than one meta query elements exist then specify the relation */
        $meta_count = count( $meta_query );
        if( $meta_count > 1 ){
            $meta_query['relation'] = 'AND';
        }

        if( $tax_count > 0 ){
            $search_args['tax_query'] = $tax_query;
        }

        /* if meta query has some values then add it to base home page query */
        if( $meta_count > 0 ){
            $search_args['meta_query'] = $meta_query;
        }

        return $search_args;
    }
    add_filter( 'inspiry_recipe_search', 'inspiry_recipe_search' );
}



if( !function_exists( 'inspiry_image_upload' ) ) {
    /**
     * Ajax image upload for recipe submit and update
     */
    function inspiry_image_upload( ) {

        // Verify Nonce
        $nonce = $_REQUEST['nonce'];
        if ( ! wp_verify_nonce( $nonce, 'inspiry_allow_upload' ) ) {
            $ajax_response = array(
                'success' => false ,
                'reason' => esc_html__('Security check failed!', 'inspiry-recipe-press')
            );
            echo json_encode( $ajax_response );
            die;
        }

        $submitted_file = $_FILES['inspiry_upload_file'];
        $uploaded_image = wp_handle_upload( $submitted_file, array( 'test_form' => false ) );   //Handle PHP uploads in WordPress, sanitizing file names, checking extensions for mime type, and moving the file to the appropriate directory within the uploads directory.

        if ( isset( $uploaded_image['file'] ) ) {
            $file_name          =   basename( $submitted_file['name'] );
            $file_type          =   wp_check_filetype( $uploaded_image['file'] );   //Retrieve the file type from the file name.

            // Prepare an array of post data for the attachment.
            $attachment_details = array(
                'guid'           => $uploaded_image['url'],
                'post_mime_type' => $file_type['type'],
                'post_title'     => preg_replace( '/\.[^.]+$/', '', basename( $file_name ) ),
                'post_content'   => '',
                'post_status'    => 'inherit'
            );

            $attach_id      =   wp_insert_attachment( $attachment_details, $uploaded_image['file'] );       // This function inserts an attachment into the media library
            $attach_data    =   wp_generate_attachment_metadata( $attach_id, $uploaded_image['file'] );     // This function generates metadata for an image attachment. It also creates a thumbnail and other intermediate sizes of the image attachment based on the sizes defined
            wp_update_attachment_metadata( $attach_id, $attach_data );                                      // Update metadata for an attachment.

            $thumbnail_url = inspiry_get_thumbnail_url( $attach_data ); // return escaped url

            $ajax_response = array(
                'success'   => true,
                'url' => $thumbnail_url,
                'attachment_id'    => $attach_id
            );

            echo json_encode( $ajax_response );
            die;

        } else {
            $ajax_response = array(
                'success' => false,
                'reason' => esc_html__('Image upload failed!', 'inspiry-recipe-press')
            );
            echo json_encode( $ajax_response );
            die;
        }

    }
    add_action( 'wp_ajax_ajax_img_upload', 'inspiry_image_upload' );    // only for logged in user
}



if( !function_exists( 'inspiry_get_thumbnail_url' ) ){
    /**
     * Get thumbnail url based on attachment data
     *
     * @param $attach_data
     * @return string
     */
    function inspiry_get_thumbnail_url( $attach_data ){
        $upload_dir         =   wp_upload_dir();
        $image_path_array   =   explode( '/', $attach_data['file'] );
        $image_path_array   =   array_slice( $image_path_array, 0, count( $image_path_array ) - 1 );
        $image_path         =   implode( '/', $image_path_array );
        $thumbnail_name     =   $attach_data['sizes']['thumbnail']['file'];
        return esc_url( $upload_dir['baseurl'] . '/' . $image_path . '/' . $thumbnail_name ) ;
    }
}



if ( !function_exists( 'inspiry_remove_gallery_image' ) ) {
    /**
     * recipe Submit Form - Gallery Image Removal
     */
    function inspiry_remove_gallery_image() {

        // Verify Nonce
        $nonce = $_POST['nonce'];
        if ( ! wp_verify_nonce ( $nonce, 'inspiry_allow_upload' ) ) {
            $ajax_response = array(
                'post_meta_removed' => false ,
                'attachment_removed' => false ,
                'reason' => esc_html__('Security check failed!', 'inspiry-recipe-press')
            );
            echo json_encode( $ajax_response );
            die;
        }

        $post_meta_removed = false;
        $attachment_removed = false;

        if( isset( $_POST['recipe_id'] ) && isset( $_POST['attachment_id'] ) ) {
            $recipe_id = intval( $_POST['recipe_id'] );
            $attachment_id = intval( $_POST['attachment_id'] );
            if ( $recipe_id > 0 && $attachment_id > 0 ) {
                $post_meta_removed = delete_post_meta( $recipe_id, 'maejstic_recipe_images', $attachment_id );
                $attachment_removed = wp_delete_attachment ( $attachment_id );
            } else if ( $attachment_id > 0 ) {
                if( false === wp_delete_attachment ( $attachment_id ) ){
                    $attachment_removed = false;
                } else {
                    $attachment_removed = true;
                }
            }
        }

        $ajax_response = array(
            'post_meta_removed' => $post_meta_removed,
            'attachment_removed' => $attachment_removed,
        );

        echo json_encode( $ajax_response );
        die;

    }
    add_action( 'wp_ajax_remove_gallery_image', 'inspiry_remove_gallery_image' );
}



if ( !function_exists( 'inspiry_submit_notice' ) ) {
    /**
     * Recipe Submit Notice Email
     *
     * @param $recipe_id
     */
    function inspiry_submit_notice( $recipe_id ) {

        // get and sanitize target email
        $target_email = inspiry_get_option( 'inspiry_submit_notice_email' );
        $target_email = is_email( $target_email );
        if ( $target_email ) {

            // current user ( submitter ) information
            $current_user = wp_get_current_user();
            $submitter_name = $current_user->display_name;
            $submitter_email = $current_user->user_email;
            $site_name = get_bloginfo( 'name' );

            // email subject
            $email_subject  = sprintf( esc_html__('A new recipe is submitted by %s at %s', 'inspiry-recipe-press'), $submitter_name, $site_name );

            // start of email body
            $email_body = $email_subject . "<br/><br/>";

            // preview link
            $preview_link = set_url_scheme( get_permalink( $recipe_id ) );
            $preview_link = esc_url( apply_filters( 'preview_post_link', add_query_arg( 'preview', 'true', $preview_link ) ) );
            if ( ! empty( $preview_link ) ) {
                $email_body .= esc_html__('You can preview it here : ','inspiry-recipe-press');
                $email_body .= '<a target="_blank" href="'. $preview_link .'">' . sanitize_text_field( $_POST['inspiry_recipe_title'] ) . '</a>';
                $email_body .= "<br/><br/>";
            }

            // message to reviewer
            if ( isset( $_POST['message_to_reviewer'] ) ) {
                $message_to_reviewer = stripslashes( $_POST['message_to_reviewer'] );
                if ( ! empty( $message_to_reviewer ) ) {
                    $email_body .= sprintf( esc_html__('Message to the Reviewer : %s','inspiry-recipe-press'), $message_to_reviewer ) . "<br/><br/>";
                }
            }

            // end of message body
            $email_body .= sprintf( esc_html__( 'You can contact the submitter "%s" via email %s', 'inspiry-recipe-press' ), $submitter_name, $submitter_email ) . "<br/>";

            // email header
            $header = 'Content-type: text/html; charset=utf-8' . "\r\n";
            $header = apply_filters ( "inspiry_recipe_submit_mail_header", $header );
            $header .= 'From: ' . $submitter_name . " <" . $submitter_email . "> \r\n";

            // Send Email
            if ( ! inspiry_email_handler( $target_email, $email_subject, $email_body, $header ) ){
                inspiry_log( 'Failed to send recipe submit notice' );
            }

        }

    }
    add_action( 'inspiry_after_recipe_submit', 'inspiry_submit_notice' );
}