<?php
/**
 * Home Latest News Variation One
 */

$news_title = inspiry_get_option( 'inspiry_home_latest_news_title' );
$news_count = inspiry_get_option( 'inspiry_home_latest_news_count' );


// getting corner image of this section
$corner_image = inspiry_get_option( 'inspiry_home_news_corner_image', 'url' );
$corner_image_side = inspiry_get_option( 'inspiry_home_news_corner_image_side' );

// Latest news related options
$latest_news_type = inspiry_get_option( 'inspiry_home_latest_news_type' );
$latest_news_category = inspiry_get_option( 'inspiry_home_latest_news_category' );
$latest_news_tag = inspiry_get_option( 'inspiry_home_latest_news_tag' );
$latest_news_skip_ids = inspiry_get_option( 'inspiry_home_skip_post_ids' );


// setting up post arguments
$post_args = array (
    'post_type' => 'post', // custom post type name
    'no_found_rows' => true, // in case of no pagination needed
    'update_post_meta_cache' => false, // post meta will not be utilized
    'update_post_term_cache' => false, // taxonomy terms will not be utilized.
    'posts_per_page' => $news_count, // listing specific number of posts
    'ignore_sticky_posts' => true,
    'tax_query' =>  array(
        array(
            'taxonomy' => 'post_format',
            'field'    => 'slug',
            'terms'    => array(
                'post-format-audio',
                'post-format-quote'
            ),
            'operator' => 'NOT IN'
        )
    ),
    'meta_query' => array(
	    array(
		    'key' => '_thumbnail_id'
	    )
    )
);

if( $latest_news_type == 'category' ){
    if(!empty( $latest_news_category )){
        $post_args['category__in'] = array( $latest_news_category );
    }
} elseif( $latest_news_type == 'tag') {
    if(!empty( $latest_news_tag )){
        $post_args['tag__in'] = array( $latest_news_tag );
    }
}

$skip_ids = false;
if(!empty( $latest_news_skip_ids )){
    $all_string = explode( ',', $latest_news_skip_ids );

    foreach( $all_string as $id ){
        $skip_ids[] = $id;
    }

	$post_args['post__not_in'] = $skip_ids;
}


$post_query = new WP_Query( $post_args );

if( $post_query->have_posts() ) :
    ?>
    <div class="latest-news animation wow fadeIn">
        <div class="container">
            <?php
            if( $news_title ) {
                ?>
                <div class="container-tags">
                    <span class="tag">
                        <span class="tag-inner"><?php echo esc_html( $news_title ); ?></span>
                    </span>
                </div>
                <?php
            }
            ?>

            <div class="wrapper-latest-news">

                <?php
                while( $post_query->have_posts() ) :
                    $post_query->the_post();
                    global $post;

                    $format = get_post_format( $post->ID );
                    if ( false === $format ) {
                        $format = 'standard';
                    }
                ?>
                <article class="news-single">
                    <div class="news-visuals">
                        <?php
                        if( $format == 'standard' || $format == 'image' ) {
                            ?>
                            <a href="<?php the_permalink(); ?>">
                                <?php
                                the_post_thumbnail( 'inspiry-whats-hot-recipe-thumbs-small' );
                                ?>
                            </a>
                            <?php

                        } elseif( $format == 'gallery' ) {

                            $gallery_images = inspiry_get_post_meta( 'inspiry_meta_gallery', array( 'type' => 'image_advanced', 'size' => 'inspiry-whats-hot-recipe-thumbs-small' ), $post->ID );
                            if( !empty( $gallery_images ) ) {
                                ?>
                                <div class="latest-news-slider">
                                    <?php
                                    foreach( $gallery_images as $gallery_image ) {
                                        $caption = ( !empty( $gallery_image['caption'] ) ) ? $gallery_image['caption'] : $gallery_image['alt'];
                                        ?>
                                        <div>
                                            <a class="swipebox" data-rel="gallery-<?php echo esc_attr( $post->ID ); ?>" href="<?php echo esc_url( $gallery_image['full_url'] ); ?>" title="<?php echo esc_attr( $caption ); ?>" >
                                                <img src="<?php echo esc_url( $gallery_image['url'] ); ?>" alt="<?php echo esc_attr( $gallery_image['title'] ); ?>"/>
                                            </a>
                                        </div>
                                        <?php
                                    }
                                    ?>
                                </div>
                                <?php
                            } elseif( has_post_thumbnail() ){

                                the_post_thumbnail( 'inspiry-whats-hot-recipe-thumbs-small' );

                            }
                        } elseif( $format == 'video' ){

                            $embed_code = get_post_meta( $post->ID, 'inspiry_meta_embed_code', true );

                            if( !empty( $embed_code ) ) {

                                 echo stripslashes( wp_specialchars_decode( $embed_code ) );

                            } elseif( has_post_thumbnail() ) {

                                the_post_thumbnail( 'inspiry-whats-hot-recipe-thumbs-small' );

                            }
                        }
                        ?>
                    </div>
                    <div class="news-detail">
                        <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>
                        <ul class="news-post-meta post-meta sb-line">
                            <li class="author"><i class="fas fa-user"></i>
                                <?php
                                printf(
                                    _x( ' %s', 'author byline', 'inspiry-recipe-press' ),
                                    sprintf(
                                        '<a class="vcard fn" href="%1$s">%2$s</a>',
                                        esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
                                        esc_html( get_the_author_meta( 'display_name' ) )
                                    )
                                );
                                ?>
                            </li>
                            <li class="date"><i class="far fa-calendar-alt"></i> <?php the_time( 'd/m/Y' ); ?></li>
                        </ul>
                        <p>
	                        <?php
	                        echo wp_trim_words( get_the_excerpt(), 9 );
	                        ?>
                        </p>
                        <a class="more" href="<?php the_permalink(); ?>"><?php esc_html_e( 'more', 'inspiry-recipe-press' ); ?> <i class="fas fa-angle-double-right"></i></a>
                    </div>
                </article>
                    <?php
                endwhile;

                // Adding corner image
                echo inspiry_gen_corner_image( $corner_image, $corner_image_side, 'news-corner-image' );
                ?>
            </div>
        </div>
    </div>
    <?php
endif;
?>