<?php
/**
 * Related Recipes
 */

global $post;

$related_titles = inspiry_get_option( 'inspiry_related_recipes_title' );
$related_type = inspiry_get_option( 'inspiry_related_recipes_type' );
$related_count = inspiry_get_option( 'inspiry_related_recipes_count' );
if( empty( $related_count ) ){
	$related_count = 3;
}

$related_args = array (
    'post_type' => 'inspiry_recipes',
    'ignore_sticky_posts' => 1,
    'no_found_rows' => true, // in case of no pagination needed
    'update_post_meta_cache' => false, // post meta will not be utilized
    'update_post_term_cache' => false, // taxonomy terms will not be utilized.
    'posts_per_page' => $related_count, // best practice other than -1 value
    'meta_query' => array(array('key' => '_thumbnail_id')), // get posts only with thumbnails
    'post__not_in' => array( $post->ID )
);

if( $related_type == 'tags' ){

    $post_tags = get_the_tags( $post->ID );
    $recipe_tags_array = array();
    if( !empty( $recipe_tags_array ) ){

        foreach( $post_tags as $tag ){
            $recipe_tags_array = $tag->term_id;
        }

        $related_args['tag__in'] = $recipe_tags_array;
    }



} elseif( $related_type == 'type' ){

    $recipe_terms = wp_get_post_terms( $post->ID, 'recipe-type', array( 'fields' => 'ids') );
    $terms_array = array();
    foreach( $recipe_terms as $term_id ){
        $terms_array[] = $term_id;
    }
    $related_args['tax_query'] = array(
        array(
            'taxonomy' => 'recipe-type',
            'field'    => 'term_id',
            'terms'    => $terms_array
        )
    );

} elseif( $related_type == 'cuisine' ){

    $recipe_terms = wp_get_post_terms( $post->ID, 'inspiry-cuisine', array( 'fields' => 'ids') );
    $terms_array = array();
    foreach( $recipe_terms as $term_id ){
        $terms_array[] = $term_id;
    }
    $related_args['tax_query'] = array(
        array(
            'taxonomy' => 'inspiry-cuisine',
            'field'    => 'term_id',
            'terms'    => $terms_array
        )
    );

} elseif( $related_type == 'course' ){

    $recipe_terms = wp_get_post_terms( $post->ID, 'inspiry-course', array( 'fields' => 'ids') );
    $terms_array = array();
    foreach( $recipe_terms as $term_id ){
        $terms_array[] = $term_id;
    }
    $related_args['tax_query'] = array(
        array(
            'taxonomy' => 'inspiry-course',
            'field'    => 'term_id',
            'terms'    => $terms_array
        )
    );
}

$related_query = new WP_Query( $related_args ) ;


if( $related_query->have_posts() ):
?>
<div class="related-recipes">
    <?php echo !empty( $related_titles ) ? '<h3 class="lined">' . esc_html( $related_titles ) . '</h3>' : ''; ?>
    <div class="boxed-recipes text-center">
        <?php
        while( $related_query->have_posts() ):
            $related_query->the_post();
        ?>
        <div class="recipe-single">
            <div class="recipe-image">
                <a href="<?php the_permalink(); ?>">
                    <?php the_post_thumbnail( 'inspiry-recipe-listing-thumbs' ); ?>
                </a>
            </div>
            <div class="outer-detail">
                <div class="detail">
                    <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>

                    <div class="short-separator"></div>
                    <div class="rating-box">
	                    <?php
	                    if( function_exists( 'inspiry_recipe_rating' ) ){
		                    inspiry_recipe_rating( $post->ID );
	                    }
	                    if( function_exists( 'inspiry_get_avg_rating' ) ){
		                  ?><span class="rating-figure">(<?php echo inspiry_get_avg_rating( $post->ID ); ?>/ 5)</span><?php
	                    }
	                    ?>
                    </div>
                </div>
            </div>
        </div>
        <?php
        endwhile;
        ?>
    </div>
</div>
<?php
endif;
wp_reset_postdata();
?>